==> ocaml_4.11.1.orig.tar.xz: ocaml-4.11.1/debugger/unix_tools.mli <==
(**************************************************************************)
(*                                                                        *)
(*                                 OCaml                                  *)
(*                                                                        *)
(*           Jerome Vouillon, projet Cristal, INRIA Rocquencourt          *)
(*           OCaml port by John Malecki and Xavier Leroy                  *)
(*                                                                        *)
(*   Copyright 1996 Institut National de Recherche en Informatique et     *)
(*     en Automatique.                                                    *)
(*                                                                        *)
(*   All rights reserved.  This file is distributed under the terms of    *)
(*   the GNU Lesser General Public License version 2.1, with the          *)
(*   special exception on linking described in the file LICENSE.          *)
(*                                                                        *)
(**************************************************************************)

(**************************** Tools for Unix ***************************)

open Unix

(* Convert a socket name into a socket address. *)
val convert_address : string -> socket_domain * sockaddr

(* Report an unix error. *)
val report_error : exn -> unit

(* Find program `name' in `PATH'. *)
(* Return the full path if found. *)
(* Raise `Not_found' otherwise. *)
val search_in_path : string -> string

(* Path expansion. *)
val expand_path : string -> string

val make_absolute : string -> string

==> ocaml_5.4.0.orig.tar.xz: ocaml-5.4.0/debugger/unix_tools.mli <==
(**************************************************************************)
(*                                                                        *)
(*                                 OCaml                                  *)
(*                                                                        *)
(*           Jerome Vouillon, projet Cristal, INRIA Rocquencourt          *)
(*           OCaml port by John Malecki and Xavier Leroy                  *)
(*                                                                        *)
(*   Copyright 1996 Institut National de Recherche en Informatique et     *)
(*     en Automatique.                                                    *)
(*                                                                        *)
(*   All rights reserved.  This file is distributed under the terms of    *)
(*   the GNU Lesser General Public License version 2.1, with the          *)
(*   special exception on linking described in the file LICENSE.          *)
(*                                                                        *)
(**************************************************************************)

(**************************** Tools for Unix ***************************)

open Unix

(* Convert a socket name into a socket address. *)
val convert_address : string -> addr_info

(* Report an unix error. *)
val report_error : exn -> unit

(* Find program `name' in `PATH'. *)
(* Return the full path if found. *)
(* Raise `Not_found' otherwise. *)
val search_in_path : string -> string

(* Path expansion. *)
val expand_path : string -> string

val make_absolute : string -> string
